@@ -2,10 +2,10 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_users.pl,v 1.35 2004/02/05 12:02:17 yeupou Exp $
+# $Id: sv_users.pl,v 1.36 2004/06/26 10:04:14 yeupou Exp $
 #
-#  Copyright 2001      (c) Loic Dachary <loic@gnu.org> (sv_cvs.pl)
-#            2003-2004 (c) Mathieu Roy <yeupou@gnu.org> 
+#  Copyright 2001      (c) Loic Dachary <loic--at--gnu.org> (sv_cvs.pl)
+#            2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org> 
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -63,6 +63,9 @@ my $usermod = "usermod";
 my $userdel = "userdel";
 my $userx_prefix;
 
+my $min_uid = "5000";
+my $nobody_uid = 
+
 my $one_group = 0;
 
 my $svusersgroup = "svusers"; # this could be configurable, however it
@@ -248,18 +251,28 @@ print LOG strftime "[$script] %c - database infos grabbed\n", localtime;
 #    as lists for each user.
 #    ( @{$etc_password{$user}} )
 #    Find what is the maximum id number known.
-#    Additionally, create a list of users.
+#    Additionally, create a list of users. 
 my %etc_password;
 my @etc_users;
 my $etc_password_maxid = -1;
 while (my @entry = getpwent()) {
     push(@etc_users, $entry[0]);
-    $etc_password_maxid = $entry[2] > $etc_password_maxid ? $entry[2] : $etc_password_maxid;
+ 
+    # Ignore special users like webcvs, anoncvs and nobody
+    # The first ones are supposed to be under 5000 (min uid). The latest
+    # will require special attention later, to avoid uid conflicts, being
+    # usually equal to 65534. To avoid troubles, we save its value.
+    if ($entry[0] eq 'nobody') { $nobody_uid = $entry[2]; }
     next if($entry[0] eq 'anoncvs' || $entry[0] eq 'webcvs' || $entry[0] eq 'nobody');
+    
+    $etc_password_maxid = $entry[2] > $etc_password_maxid ? $entry[2] : $etc_password_maxid;
+    
     $etc_password{$entry[0]} = [ @entry ];
     print "DBG etc: user $entry[0]\t\t maxid $etc_password_maxid\n" if $debug;
 }
 $etc_password_maxid++;
+# If we did not reached the minimal uid, set it as maxid
+$etc_password_maxid = $min_uid if $min_uid > $etc_password_maxid;
 
 # /etc/group:
 #    Create an hash that contains users infos about groups,
@@ -402,7 +415,11 @@ foreach my $user (@only_in_db){
 	    
 	}
 	
-	$etc_password_maxid++;
+	# Increment the uid for the next user, avoid the special value 
+	# attributed to nobody.
+	$etc_password_maxid++;	
+	$etc_password_maxid++ if $etc_password_maxid == $nobody_uid;
+
 	print LOG strftime "[$script] %c ---- $useradd $user ($etc_password_maxid, $email, $home, $ssh_keys_count ssh keys, $gpg_keys_count gpg) $groups\n", localtime;
     }
 
