@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_update_conf.pl,v 1.23 2004/08/23 12:47:54 yeupou Exp $
+# $Id: sv_update_conf.pl,v 1.24 2004/08/24 06:21:37 yeupou Exp $
 #
 #
 #
@@ -154,6 +154,11 @@ sub AskSetting {
     } else {
 	$item_previous_answer = "OUT";
     }
+    if ($_[5]) {
+	$item_quotes = "'";
+    } else {
+	$item_quotes = "\"";
+    }
     
     # Get user input if in interactive mode
     if (!$non_interactive) {
@@ -171,12 +176,12 @@ sub AskSetting {
     # Now, we set $$item to how we want to show it in the configuration
     # file.
     if ($$item eq "" || $$item eq "OUT") {
-	$$item = "# our \$$item=\'\'\;";
+	$$item = "# our \$$item=$item_quotes$item_quotes\;";
     } else {
 	# Escape quotes
-	$$item =~ s/\'/\\\'/g;
+	$$item =~ s/$item_quotes/\\$item_quotes/g;
 	# Add the entry
-	$$item = "our \$$item=\'$$item\'\;"; 	
+	$$item = "our \$$item=$item_quotes$$item$item_quotes\;"; 	
     }
 }
 
@@ -229,7 +234,7 @@ if ($recreate) {
 
     ## GUI ##
 
-      AskSetting("sys_name", "Platform name", "Name shown on public pages for the whole service", "Savannah", $sys_name);
+      AskSetting("sys_name", "Platform name", "Name shown on public pages for the whole service", "Savannah", $sys_name, 1);
       AskSetting("sys_unix_group_name", "Server administration project unix name", "Unix group name of the meta-project used for administration", "savannah", $sys_unix_group_name);
 
       AskSetting("sys_default_locale", "Default locale", "It must be a valid locale name", "french", $sys_default_locale);
@@ -300,7 +305,7 @@ if ($recreate) {
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_update_conf.pl,v 1.23 2004/08/23 12:47:54 yeupou Exp $
+# $Id: sv_update_conf.pl,v 1.24 2004/08/24 06:21:37 yeupou Exp $
 #
 #
 # Savannah Site Configuration:
