@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: group_type.php,v 1.24 2004/01/31 00:56:17 yeupou Exp $
+// $Id: group_type.php,v 1.25 2004/03/06 12:31:07 toddy Exp $
 //
 //
 //
@@ -33,18 +33,18 @@ require_directory("project");
 session_require(array('group'=>'1','admin_flags'=>'A'));
 
 // group public choice
-if ($delete) 
+if ($delete)
 {
   $result = db_query("DELETE FROM group_type WHERE type_id='$form_type_id'");
-      
+
   if (!$result)
     { fb(_("Unable to delete group type"),0); }
-  else 
+  else
     { fb(_("group type deleted")); }
 
 }
 
-if ($update) { 
+if ($update) {
 
   $sql = "UPDATE group_type SET " . "name='$form_name',"
      . "description='$form_description',"
@@ -84,11 +84,11 @@ if ($update) {
      . "can_use_bug='$form_can_use_bug',"
      . "admin_email_adress='$form_admin_email_adress' WHERE "
      . "type_id='$form_type_id'";
-  
+
   $result = db_query($sql);
-     
+
   if (!$result)
-    { fb(_("Unable to update group type general settings ".db_error()),1); }
+    { fb(sprintf(_("Unable to update group type general settings: %s"), db_error()),1); }
   else
     { fb(_("group type general settings updated")); }
 
@@ -107,9 +107,9 @@ if ($update) {
 		     . "is_menu_configurable_patch='$form_is_menu_configurable_patch'"
 		     . " WHERE "
 		     . "type_id='$form_type_id'");
-     
+
   if (!$result)
-    { fb(_("Unable to update group type menu settings ". db_error()),0); }
+    { fb(sprintf(_("Unable to update group type menu settings: %s"), db_error()),0); }
   else
     { fb(_("group type menu settings updated")); }
 
@@ -118,31 +118,31 @@ if ($update) {
   $patch_flags="patch_user_";
   $support_flags="support_user_";
   $news_flags="news_user_";
-  
-  $sql = 'UPDATE group_type SET ' 
+
+  $sql = 'UPDATE group_type SET '
      ."bugs_flags=".$$bugs_flags.","
      ."news_flags=".$$news_flags.","
      ."task_flags=".$$task_flags.", "
      ."patch_flags=".$$patch_flags.", "
      ."support_flags=".$$support_flags." "
      ."WHERE type_id='$form_type_id'";
-  
+
   $result = db_query($sql);
 
   if (!$result)
-    { fb(_("Unable to update group type user permissions settings " . db_error()),0); }
+    { fb(sprintf(_("Unable to update group type user permissions settings: %s"), db_error()),0); }
   else
     { fb(_("group type user permissions settings updated")); }
 }
 
 
 
-if (!isset($type_id)) 
+if (!isset($type_id))
 {
   site_admin_header(array('title'=>'Group Type Management','toptab'=>'admgrptype'));
   $result = db_query("SELECT type_id,name FROM group_type ORDER BY type_id");
 
-  while ($usr = db_fetch_array($result)) 
+  while ($usr = db_fetch_array($result))
     {
       print '<a href="'.$PHP_SELF.'?type_id='.$usr[type_id].'">Type #'.$usr[type_id].': '.$usr[name].'</a><br>';
       $last=$usr[type_id];
@@ -150,11 +150,11 @@ if (!isset($type_id))
   $type=$last+1;
   print '<a href="'.$PHP_SELF.'?type_id='.$type.'&amp;create=1">Create new group type</a>';
 
-} 
-else 
+}
+else
 {
 
-  if ($create == "1") 
+  if ($create == "1")
     {
       db_query("INSERT INTO group_type (type_id,name) VALUES ('$type_id','New type')");
       $update_button_text = _("Create");
@@ -174,9 +174,9 @@ else
 
   print '<FORM action="'.$PHP_SELF.'" method="POST">
 <INPUT type="hidden" name="form_type_id" value="'.$type_id.'">';
-  
+
   // ####################################################################
-  // GENERAL SETTINGS 
+  // GENERAL SETTINGS
   // ####################################################################
 
   $HTML->box1_top(_("General Default Settings for Groups of this Type"));
@@ -188,7 +188,7 @@ else
   print '
 <p>Basic Help: host means hostname (as savannah.gnu.org), dir means directory (as /usr/local/savannah), url means -well- url (as http://savannah.gnu.org/blah ).
 
-<p class="warn">Everytime a project\'s unix_group_name should appear, use the special string %PROJECT. 
+<p class="warn">Everytime a project\'s unix_group_name should appear, use the special string %PROJECT.
 
 <p>Fields marked with [BACKEND SPECIFIC] are only useful is you use the savannah backend.
 
@@ -254,7 +254,7 @@ print '<br>CVS Dir (path on the filesystem) [BACKEND SPECIFIC]:<br>
 ';
   $i++;
 
-  // ########### License 
+  // ########### License
 
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
@@ -293,7 +293,7 @@ can use download area.
 			  $row_grp['dir_type_download']);
 
   print '<br>Download Dir (path on the filesystem) [BACKEND SPECIFIC]:<br>
-<input type="text" name="form_dir_download" value="'.$row_grp['dir_download'].'" size="'.$textfield_size.'"> 
+<input type="text" name="form_dir_download" value="'.$row_grp['dir_download'].'" size="'.$textfield_size.'">
 <br><br>Download Url:<br>
 <input type="text" name="form_url_download" value="'.$row_grp['url_download'].'" size="'.$textfield_size.'">
 
@@ -306,7 +306,7 @@ can use download area.
 
 <h3>Mailing list:</h3>
 
-<font class="warn">Help: Everytime a mailing-list name should appear, use the special string %LIST. Note that if you do not want the Savannah software to interact with your mail host (for instance to truly create mailing list), do not fill the mail host information.</font> 
+<font class="warn">Help: Everytime a mailing-list name should appear, use the special string %LIST. Note that if you do not want the Savannah software to interact with your mail host (for instance to truly create mailing list), do not fill the mail host information.</font>
 
 <br>
 <br><INPUT TYPE="CHECKBOX" NAME="form_can_use_mailing_list" VALUE="1"'.( ($row_grp['can_use_mailing_list']==1) ? ' CHECKED' : '' ).'>
@@ -351,7 +351,7 @@ You can force projects to follow a specific policy for the name of the %LIST. He
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
 <h3>Forum:</h3>
-<br><INPUT TYPE="CHECKBOX" NAME="form_can_use_forum" VALUE="1"'.( ($row_grp['can_use_forum']==1) ? ' CHECKED' : '' ).'> 
+<br><INPUT TYPE="CHECKBOX" NAME="form_can_use_forum" VALUE="1"'.( ($row_grp['can_use_forum']==1) ? ' CHECKED' : '' ).'>
 can use forum.
 ';
   $i++;
@@ -360,14 +360,14 @@ can use forum.
 
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
-<h3>Patch manager:</h3> 
+<h3>Patch manager:</h3>
 <br><INPUT TYPE="CHECKBOX" NAME="form_can_use_patch" VALUE="1"'.( ($row_grp['can_use_patch']==1) ? ' CHECKED' : '' ).'> can use patch manager.
 
 ';
   $i++;
-  
+
   // ###########  Task
-  
+
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
 <h3>Task manager:</h3>
@@ -385,9 +385,9 @@ can use forum.
 
 ';
   $i++;
-  
+
   // ###########  Support
-  
+
   print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">
 
 <h3>Support Request Manager:</h3>
@@ -402,21 +402,21 @@ can use forum.
 
 <h3>Bug Tracker:</h3>
 <br><INPUT TYPE="CHECKBOX" NAME="form_can_use_bug" VALUE="1"'.(($row_grp['can_use_bug']==1) ? ' CHECKED' : '' ).'> can use bug tracker.';
-  
+
   $HTML->box1_bottom();
 
 print '
-<p align="center"> 
-<input type="submit" name="update" value="'.$update_button_text.'"> &nbsp; 
+<p align="center">
+<input type="submit" name="update" value="'.$update_button_text.'"> &nbsp;
 <input type="submit" name="delete" value="'._("Delete this Group Type").'">';
 
- 
+
   print '<br><br>';
 
   // ####################################################################
-  // PROJECTS MENU SETTINGS 
+  // PROJECTS MENU SETTINGS
   // ####################################################################
- 
+
   $HTML->box1_top(_("Project Menu Settings"));
   print '<p>This form allows you to choose which menu entries are configurable by the projects administrators.</p>';
   $i = 1;
@@ -426,7 +426,7 @@ print '
       // just a little fonction to clean that part of the code, no
       // interest to generalize it
       global $i, $row_grp;
-      if ($increment) 
+      if ($increment)
 	{ $i++; }
       print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
       html_build_checkbox("form_is_menu_configurable_".$val, $row_grp["is_menu_configurable_".$val]);
@@ -466,19 +466,19 @@ print '
 
   specific_checkbox("patch",
 		    _("the patch tracker link can be modified"));
-  
+
   print '</td></tr><tr><td class="'.utils_get_alt_row_color(1).'">';
-  
+
 
   $HTML->box1_bottom();
 
-  print '<p align="center"><input type="submit" name="update" value="'.$update_button_text.'"> &nbsp; 
+  print '<p align="center"><input type="submit" name="update" value="'.$update_button_text.'"> &nbsp;
 <input type="submit" name="delete" value="'._("Delete this Group Type").'">';
 
-  print '<br><br>'; 
+  print '<br><br>';
 
   // ####################################################################
-  // PROJECTS USERS SETTINGS 
+  // PROJECTS USERS SETTINGS
   // ####################################################################
 
   $HTML->box1_top(_("Project Default Users Permissions"));
@@ -492,20 +492,20 @@ print '
   $title_arr[]=_("Patch Tracking");
   $title_arr[]=_("News Manager");
   print html_build_list_table_top ($title_arr);
-  
+
   html_select_permission_box("support", $row_grp['support_flags'], "type");
   html_select_permission_box("bugs", $row_grp['bugs_flags'], "type");
   html_select_permission_box("task", $row_grp['task_flags'], "type");
-  html_select_permission_box("patch", $row_grp['patch_flags'], "type");     
+  html_select_permission_box("patch", $row_grp['patch_flags'], "type");
   html_select_permission_box("news", $row_grp['news_flags'], "type");
-  
+
   print '  </tr>
 </table>';
-  
+
   $HTML->box1_bottom();
 
   print '<p align="center">
-<input type="submit" name="update" value="'.$update_button_text.'"> &nbsp; 
+<input type="submit" name="update" value="'.$update_button_text.'"> &nbsp;
 <input type="submit" name="delete" value="'._("Delete this Group Type").'"></p>
 </form>';
 
