@@ -2,9 +2,10 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: database.php,v 1.8 2004/03/13 18:22:06 yeupou Exp $
+# $Id: database.php,v 1.10 2004/06/29 09:49:31 yeupou Exp $
 #  Copyright 1999-2000 (c) The SourceForge Crew
-# 
+#            2004      (c) Elfyn McBratney <elfyn--at--emcb.co.uk>
+#
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
@@ -22,8 +23,19 @@
 function db_connect() 
 {
   global $sys_dbhost,$sys_dbuser,$sys_dbpasswd,$conn;
-  $conn = mysql_connect($sys_dbhost,$sys_dbuser,$sys_dbpasswd);
-#return $conn;
+
+  # If persistant MySQL links are enabled, try and open a
+  # persistant link.
+  $mysql_persistant_links = ini_get('mysql.allow_persistent');
+  if (strtolower($mysql_persistant_links) == 'on' || $mysql_persistant_links == '1' ) {
+    $conn = mysql_pconnect($sys_dbhost,$sys_dbuser,$sys_dbpasswd);
+  }
+
+  # If $conn is not a valid resource, try and open a normal
+  #x (non persistant) link.
+  if (!is_resource($conn)) {
+    $conn = mysql_connect($sys_dbhost,$sys_dbuser,$sys_dbpasswd);
+  }
 }
 
 function db_query($qstring,$print=0) 
