@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: exit.php,v 1.11 2004/03/13 18:22:06 yeupou Exp $
+# $Id: exit.php,v 1.12 2004/06/28 14:21:32 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -41,17 +41,7 @@ function exit_error($title,$text=0)
   
   if ($text)
     {
-      if ($text == "nogroup") 
-	{
-	  $HTML->box1_top('Search a group on Savannah');
-	  search_box();
-	  $HTML->box1_bottom();
-	  
-	} 
-      else
-	{
-	  print '<p>'.$text.'</p>';
-	}
+      print '<p>'.$text.'</p>';
     }
   $HTML->footer(array());
   exit;
