@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: html.php,v 1.48 2004/03/30 07:20:01 yeupou Exp $
+# $Id: html.php,v 1.51 2004/06/26 11:50:42 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -61,6 +61,12 @@ function html_nextprev ($search_url, $rows, $rows_returned)
     }
 }
 
+function html_anchor ($content, $name) 
+{
+  if (!$name) { $name = $content; };
+  return '<a name="'.$name.'" href="#'.$name.'">'.$content.'</a>';
+}
+
 function html_feedback_top()
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_feedback_top() ';
