@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: menu.php,v 1.107 2004/02/15 12:40:38 yeupou Exp $
+# $Id: menu.php,v 1.110 2004/03/27 11:18:11 yeupou Exp $
 #
-# Copyright 1999-2000 (c) The SourceForge Crew
-# Copyright 2000-2003 (c) Free Software Foundation
+#  Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2000-2003 (c) Free Software Foundation
 #
-# Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
-#                         Yves Perrin <yves.perrin--at--cern.ch>
+#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#                          Yves Perrin <yves.perrin--at--cern.ch>
 # 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -127,7 +127,7 @@ function menu_valid_html()
   $HTML->menuhtml_bottom();
 }
 
-function menu_loggedin($page_title) 
+function menu_loggedin($page_title, $page_toptab=0, $page_group=0) 
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_loggedin($page_title) ';
   global $HTML;
@@ -140,7 +140,13 @@ function menu_loggedin($page_title)
   $HTML->menu_entry($GLOBALS['sys_home'].'account/',_("My Account Conf"));
   if (!$GLOBALS['HTTP_POST_VARS']) 
     {
-      $bookmark_title = urlencode( str_replace('Savannah: ', '', $page_title));
+      $bookmark_title = "";
+      if ($page_toptab) 
+	{ $bookmark_title .= urlencode(title_toptab($page_toptab, $page_group)); }
+      if ($page_title) 
+	{ $bookmark_title .= urlencode(_(": ").$page_title); }
+
+
       $HTML->menu_entry($GLOBALS['sys_home'].'my/bookmark_add.php?bookmark_url='.urlencode($GLOBALS['REQUEST_URI']).'&amp;bookmark_title='.$bookmark_title,_("Bookmark This Page"));
     }
   $HTML->menu_entry($GLOBALS['sys_home'].'account/logout.php',_("Logout"));
@@ -173,7 +179,7 @@ function menu_print_sidebar($params)
     } 
   else
     {
-      echo menu_loggedin($params['title']);
+      echo menu_loggedin($params['title'], $params['toptab'], $params['group']);
     }
   echo menu_search();
   # Site Admin menu added here
