@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: pre.php,v 1.74 2004/03/27 11:18:11 yeupou Exp $
+# $Id: pre.php,v 1.76 2004/07/03 18:22:03 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -48,6 +48,17 @@ else
 # the include area (all include files of a module are arranged
 # in subdirectories in the includes area, so this routine sources
 # just all of the *.php files found in the module's subdirectory). 
+
+# Prevent declaration by users.
+if ($_GET['module'] ||
+    $_POST['module'] ||
+    $_COOKIE['module'] || 
+    $_SERVER['module'] ||
+    $_ENV['module'] ||
+    $_FILES['module'] ||
+    $_REQUEST['module'])
+{ exit(); }    
+
 function require_directory ($module) 
 {
 	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':require_directory ($module) ';
@@ -165,6 +176,9 @@ require $GLOBALS['sys_urlroot'].'/include/sendmail.php';
 # various html libs like button bar, themable
 require $GLOBALS['sys_urlroot'].'/include/html.php';
 
+# graphics library
+require $GLOBALS['sys_urlroot'].'/include/graphs.php';
+
 # calendar library
 require $GLOBALS['sys_urlroot'].'/include/calendar.php';
 
