@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sendmail.php,v 1.9 2004/02/12 16:34:08 yeupou Exp $
+# $Id: sendmail.php,v 1.11 2004/03/26 18:45:45 yeupou Exp $
 #
 #  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
@@ -26,7 +26,16 @@
 # Every mail sent by Savannah should be using that function which
 # works like mail().
 # Note: $to can be a coma-separated list.
-function sendmail_mail ($from, $to, $subject, $message, $savannah_project=0, $savannah_artifact=0, $savannah_artifact_id=0, $reply_to=0, $additional_headers=0) 
+#       $from and $to can contain user names
+function sendmail_mail ($from, 
+			$to, 
+			$subject, 
+			$message, 
+			$savannah_project=0, 
+			$savannah_artifact=0, 
+			$savannah_artifact_id=0, 
+			$reply_to=0, 
+			$additional_headers=0) 
 {
 	
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':sendmail_mail  ';
@@ -42,60 +51,72 @@ function sendmail_mail ($from, $to, $subject, $message, $savannah_project=0, $sa
   $xcopy = $to;
   $to = array_unique(explode(",", ereg_replace(" ", "", $to)));
 
+  # If $from is a login name, write nice From: field
+  $fromuid = user_getid($from);
+  if (user_exists($fromuid)) 
+    {
+      $from = user_getrealname($fromuid, 1)." <".user_getemail($fromuid).">";
+    }
+
   # Write the add. headers 
   $more_headers = "From: ".$from."\n";
   if ($reply_to)
     { $more_headers .= "Reply-To: ".$reply_to."\n"; }
-  $more_headers .= "X-Savannah-Server: ".$GLOBALS['SERVER_NAME'].":".$GLOBALS['SERVER_PORT']." [".$GLOBALS['SERVER_ADDR']."]\n";
+  $more_headers .= "X-Savane-Server: ".$GLOBALS['SERVER_NAME'].":".$GLOBALS['SERVER_PORT']." [".$GLOBALS['SERVER_ADDR']."]\n";
   if ($savannah_project) 
-    { $more_headers .= "X-Savannah-Project: ".$savannah_project."\n"; }
+    { $more_headers .= "X-Savane-Project: ".$savannah_project."\n"; }
   if ($savannah_artifact) 
-    { $more_headers .= "X-Savannah-Artifact: ".$savannah_artifact."\n"; }  
+    { $more_headers .= "X-Savane-Artifact: ".$savannah_artifact."\n"; }  
   if ($savannah_artifact_id) 
-    { $more_headers .= "X-Savannah-Artifact-ID: ".$savannah_artifact_id."\n"; }
+    { $more_headers .= "X-Savane-Artifact-ID: ".$savannah_artifact_id."\n"; }
   if ($additional_headers) 
     { $more_headers .= $additional_headers."\n";  }
   $more_headers .= "User-Agent: ".$GLOBALS['HTTP_USER_AGENT']."\n";
   $more_headers .= "X-Apparently-From: ".$GLOBALS['REMOTE_ADDR']."\n";
-  $more_headers .= "X-Copy-To: ".$xcopy; # persons in Cc, [bugs #6821]
   
   # Add eventually info on the subject
   if ($savannah_artifact && $savannah_artifact_id) 
     { $subject = "[".$savannah_artifact." #".$savannah_artifact_id."] ".$subject; }
-    
+  
   # Add a signature for the server
   $message .= "\n\n_______________________________________________
   ".sprintf(_("Message sent via/by %s"), $GLOBALS['sys_name'])."
   http://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home']."\n";
+  
+  # Forge the real to list, by parsing every item of the $to list
+  unset($real_to);
 
-  # Send it
   while (list($k,$v) = each($to)) 
     {
-      
-      # If an address is a username (no @), get the email address from
-      # the database.
-      # If nothing is found, just let the username (there's maybe a 
-      # local alias).
+    # If an address is a username, get the email address from
+    # the database.
+    # If nothing is found, just let the username - there's maybe a 
+    # local alias.
       if (!ereg("@", $v)) 
 	{
 	  if (user_exists($v)) 
-	    { 
-	      $v = user_getemail($v); 
-	    }
-	}
-      
-      # Send the mail
-      if ($v) 
+            { $v = user_getrealname($v, 1)." <".user_getemail($v).">"; }
+        }
+    # If $v is set, add it to the list
+    $real_to .= $v.", ";
+
+    } 
+ 
+   # Remove the extra ", " at the end of the list
+   $real_to = substr($real_to,0,-2);
+
+   # Send the mail
+   if ($real_to) 
 	{
-	  $ret .= mail($v, $subject, $message, $more_headers);
-	  fb(sprintf(_("Mail sent to %s"), utils_antispam_email($v)));
+	  $ret .= mail($real_to, $subject, $message, $more_headers);
+	  fb(sprintf(_("Mail sent to %s"), utils_antispam_email($real_to)));
 	} 
       else 
 	{
 	  fb(_("warning: a mail notification cannot be sent, the To: header being missing. please contact administrators"), 1);
 	}
       
-    }
+  dbg("mail sent to $real_to, $subject, from $from ($fromuid)");
   return $ret; 
 }
 
@@ -108,13 +129,14 @@ function sendmail_form_message ($form_action, $user_id)
   print '<p class="warn">'.("If you are writing for help, did you read the project 
 documentation first? Try to provide any potentially useful information you can think of.").'</p>';
 
+  # We do not really bother finding out the realname + email, sendmail_mail()
+  # will do it.
   print '
  <form action="'.$form_action.'" method="post">
    <input type="hidden" name="touser" value="'.$user_id.'">
-   <input type="hidden" name="email" value="'.user_getemail(user_getid()).'">
-   <input type="hidden" name="name" value="'.user_getrealname(user_getid()).'">
+   <input type="hidden" name="fromuser" value="'.user_getname().'">
 
-   <p><font class="preinput">'._("From:").'</font> '.user_getrealname(user_getid()).' &lt;'.user_getemail(user_getid()).'&gt;<br />
+   <p><font class="preinput">'._("From:").'</font> '.user_getrealname(user_getid(), 1).' &lt;'.user_getemail(user_getid()).'&gt;<br />
     <font class="preinput">'._("Mailer:").'</font> '.$GLOBALS['HTTP_USER_AGENT'].' - '.$GLOBALS['REMOTE_ADDR'].'</p>
    <p><font class="preinput">'._("Subject:").'</font><br />
    &nbsp;&nbsp;&nbsp;<input type="text" name="subject" size="60" maxlength="45" value=""></p>
