@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: data.php,v 1.13 2004/03/26 17:38:04 yeupou Exp $
+# $Id: data.php,v 1.15 2004/06/28 14:21:32 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -1297,7 +1297,7 @@ function trackers_data_get_valid_bugs ($group_id=false,$item_id='')
 function trackers_data_get_followups ($item_id=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_get_followups ($item_id=false)';
-  $sql="SELECT DISTINCT ".ARTIFACT."_history.bug_history_id,".ARTIFACT."_history.field_name,".ARTIFACT."_history.old_value,".ARTIFACT."_history.date,user.user_name,".ARTIFACT."_field_value.value AS comment_type ".
+  $sql="SELECT DISTINCT ".ARTIFACT."_history.bug_history_id,".ARTIFACT."_history.field_name,".ARTIFACT."_history.old_value,".ARTIFACT."_history.date,user.user_name,user.realname,".ARTIFACT."_field_value.value AS comment_type ".
      "FROM ".ARTIFACT."_history,".ARTIFACT."_field_value,".ARTIFACT."_field,".ARTIFACT.",user ".
      "WHERE ".ARTIFACT."_history.bug_id='$item_id' ".
      "AND ".ARTIFACT."_history.field_name = 'details' ".
@@ -1579,6 +1579,7 @@ function trackers_data_handle_update ($group_id,
   $result = true;
   if ($upd_list)
     {
+      dbg($upd_list);
       # strip the excess comma at the end of the update field list
       $upd_list = substr($upd_list,0,-1);
 
