@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: add.php,v 1.17 2004/03/13 18:22:06 yeupou Exp $
+# $Id: add.php,v 1.18 2004/06/08 23:37:01 beuc Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -48,9 +48,7 @@ print '<form action="'.$PHP_SELF.'" method="post" enctype="multipart/form-data"
 	<input type="hidden" name="group_id" value="'.$group_id.'">
 	<table cellpadding="0">
 	<tr><td valign="top" colspan="'.(2*$fields_per_line).'">
-        </td></tr>
-        
-        <script language="JavaScript" src="'.$GLOBALS['sys_home'].'include/calendar.js"></script>';
+        </td></tr>';
 
 
 
