@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: mod.php,v 1.6 2004/03/13 18:22:06 yeupou Exp $
+# $Id: mod.php,v 1.13 2004/06/28 10:30:44 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -36,6 +36,14 @@ $result=db_query($sql);
 if (db_numrows($result) > 0) 
 {
   
+  # Defines the item name, converting bugs to bug.
+  # (Ideally, the artifact bugs should be named bug)
+  if (ARTIFACT == "bugs") 
+    { $item_name = "bug #".$item_id; }
+  else
+    { $item_name = ARTIFACT." #".$item_id; }
+
+
   # Prepare all the necessary fields in case the user wants to 
   # Create a new task based on this bug
   
@@ -93,9 +101,9 @@ if (db_numrows($result) > 0)
 
   # ################################ Start the form
 
-  print '
-    <h2>['.ARTIFACT.' #'.$item_id.'] '.db_result($result,0,'summary').'</h2>
+  print '<h2>'.sprintf(_("<i>%s</i> overview:"), $item_name).' '.db_result($result,0,'summary').'</h2>';
 
+  print '
     <form action="'.$PHP_SELF.'" method="post" enctype="multipart/form-data" name="item_form">
     <input type="hidden" name="func" value="postmoditem">
     <input type="hidden" name="group_id" value="'.$group_id.'">
@@ -104,11 +112,11 @@ if (db_numrows($result) > 0)
     <table cellpadding="0" width="100%">
       <tr>
           <td class="preinput">'._("Submitted by:").'&nbsp;</td><td>'.utils_user_link(user_getname(db_result($result,0,'submitted_by')), user_getrealname(db_result($result,0,'submitted_by'))).'</td>
-          <td colspan="6" align="center" valign="top" class="bold"><input type="submit" name="submit" value="'._("Submit Changes").'"></td>
+          <td colspan="6" align="center" valign="top"><input type="submit" name="submit" value="'._("Submit Changes and Browse Items").'" class="bold"></td>
       </tr>
       <tr>
           <td class="preinput">'._("Submitted on:").'&nbsp;</td><td>'.format_date($sys_datefmt,db_result($result,0,'date')).'</td>
-          <td>&nbsp;</td>
+          <td colspan="6" align="center" valign="top"><input type="submit" name="submitreturn" value="'._("Submit Changes and Return to this Item").'"></td>
       </tr>';
 	  
   $field_per_linex2=2*$fields_per_line;
@@ -184,9 +192,23 @@ if (db_numrows($result) > 0)
   print '</table>';
   print '<p>&nbsp;</p>';
 
+  # ################################ Shortcuts
+
+  print '<h2>'.sprintf(_("<i>%s</i> details:"), $item_name).'</h2>';
+  print '&nbsp;&nbsp;- <a href="#comments">'._("Follow-up Comments").'</a><br>';  
+  print '&nbsp;&nbsp;- <a href="#attached">'._("Attached Files").'</a><br>';
+  print '&nbsp;&nbsp;- <a href="#cc">'._("Mail Notification Carbon-Copy List").'</a><br>';
+  print '&nbsp;&nbsp;- <a href="#dependencies">'._("Dependencies").'</a><br>';
+  if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'3'))
+    {
+      print '&nbsp;&nbsp;- <a href="#reassign">'._("Reassign this item").'</a><br>'; 
+    }
+
+  print '<p>&nbsp;</p>';
+       
   # ################################ Comments 
 
-  print '<h3>' ._("Follow-up Comments").'</h3>';
+  print '<h3>'.html_anchor(_("Follow-up Comments"), 'comments').'</h3>';
   print '<table>
           <tr><td class="preinput">'
     ._("Use a Canned Response:").'&nbsp;</td><td width="70%">';
@@ -203,9 +225,9 @@ if (db_numrows($result) > 0)
 
   print '<p>';      
   printf (_("(Note: you can add pointers to others items by typing %s where %s is one of %s and %s the item id number.)"), 
-	  "<font class=\"italic\">tracker #nnn</font>",
-	  "<font class=\"italic\">tracker</font>",
-	  "<font class=\"italic\">support, bugs, task, patch</font>",
+	  "<font class=\"italic\">artifact #nnn</font>",
+	  "<font class=\"italic\">artifact</font>",
+	  "<font class=\"italic\">support, bug, task, patch</font>",
 	  "<font class=\"italic\">nnn</font>");
 
   print '<p>';      
@@ -218,7 +240,7 @@ if (db_numrows($result) > 0)
 
   # ################################ Attached Files
 
-  print '<h3>'._("Attached Files").'</h3>';
+  print '<h3>'.html_anchor(_("Attached Files"), "attached").'</h3>';
   
   print '<font class="preinput"> '._("Attach File:").'</font><br>
       &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40">
@@ -233,7 +255,7 @@ if (db_numrows($result) > 0)
 
   # ################################ Mail notification
 
-  print '<h3>'._("Mail Notification Carbon-Copy List").'</h3>';
+  print '<h3>'.html_anchor(_("Mail Notification Carbon-Copy List"), "cc").'</h3>';
   
   printf (_("(Note: for %s users, you can use their login name rather than their email addresses.)"), $GLOBALS['sys_name']);
 
@@ -249,7 +271,7 @@ if (db_numrows($result) > 0)
 
   # ################################ Dependencies
 
-  print '<h3>'._("Dependencies").'</h3>';
+  print '<h3>'.html_anchor(_("Dependencies"), "dependencies").'</h3>';
   print '<font class="preinput">';
   if (!$depends_search) 
     { print _("Search an item (to fill a dependancy against):"); }
@@ -291,13 +313,13 @@ if (db_numrows($result) > 0)
 
   if (!$depends_search) 
     { 
-      print '<input type="submit" name="submit" class="bold" value="'._("Search").'">'; 
+      print '<input type="submit" name="submit" value="'._("Search").'">'; 
     }
   else 
     { 
       # Print a specific message if we are already at step 2 of filling
       # a dependency.
-      print '<input type="submit" name="submit" class="bold" value="'._("New search").'">';
+      print '<input type="submit" name="submit" value="'._("New search").'">';
     }
 
   # Search results, if we are already at step 2 of filling
@@ -373,7 +395,7 @@ if (db_numrows($result) > 0)
 
   if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'3'))
     {
-      print '<h3>'._("Reassign this item").'</h3>';
+      print '<h3>'.html_anchor(_("Reassign this item"), "reassign").'</h3>';
         
       print '<p><font class="preinput">'
 	._("Move to the:").'</font><br>&nbsp;&nbsp;&nbsp;';
@@ -408,13 +430,13 @@ if (db_numrows($result) > 0)
       print '</font><br>&nbsp;&nbsp;&nbsp;<input type="text" name="reassign_change_project_search" size="40" maxlength="255">';
       if (!$reassign_change_project_search) 
 	{ 
-	  print ' <input type="submit" name="submit" class="bold" value="'._("Search").'">'; 
+	  print ' <input type="submit" name="submit" value="'._("Search").'">'; 
 	}
       else 
 	{ 
 	  # Print a specific message if we are already at step 2 of filling
 	  # a ressign.
-	  print ' <input type="submit" name="submit" class="bold" value="'._("New search").'">';
+	  print ' <input type="submit" name="submit" value="'._("New search").'">';
 	}
       
 
@@ -460,8 +482,10 @@ if (db_numrows($result) > 0)
 
 
   #  ################################ Submit 
-  
-  print '<p align="center"><input type="submit" name="submit" class="bold" value="'._("Submit Changes").'"></form><p>';
+ 
+  print '<p>&nbsp;</p>';
+ 
+  print '<p align="center"><input type="submit" name="submit" class="bold" value="'._("Submit Changes and Browse Items").'"> <input type="submit" name="submitreturn" value="'._("Submit Changes and Return to this Item").'"></form><p>';
   
   
   # ################################ History  
