@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: utils.php,v 1.60 2004/03/28 18:17:44 yeupou Exp $
+# $Id: utils.php,v 1.63 2004/06/30 14:10:51 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -363,10 +363,14 @@ function utils_make_links ($data='',$group_id = 0)
       $line = eregi_replace(":##", "://", $line);
 
       # Links between items
-      $line = eregi_replace("(bugs|bug)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."bugs/?func=detailitem&amp;item_id=\\2\">bug&nbsp;#\\2</a>", $line);
-      $line = eregi_replace("(support|sr)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."support/?func=detailitem&amp;item_id=\\2\">support&nbsp;#\\2</a>", $line);
-      $line = eregi_replace("task[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."task/?func=detailitem&amp;item_id=\\1\">task&nbsp;#\\1</a>", $line);
-      $line = eregi_replace("patch[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."patch/?func=detailitem&amp;item_id=\\1\">patch&nbsp;#\\1</a>", $line);
+      # FIXME: it should be i18n, but in a clever way, meaning that everytime
+      # a form is submitted with such string, the string get converted in
+      # english so we always get the links found without having a regexp
+      # including every possible language.
+      $line = eregi_replace("(bugs|bug)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."bugs/?func=detailitem&amp;item_id=\\2\" class=\"italic\">bug&nbsp;#\\2</a>", $line);
+      $line = eregi_replace("(support|sr)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."support/?func=detailitem&amp;item_id=\\2\" class=\"italic\">support&nbsp;#\\2</a>", $line);
+      $line = eregi_replace("task[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."task/?func=detailitem&amp;item_id=\\1\" class=\"italic\">task&nbsp;#\\1</a>", $line);
+      $line = eregi_replace("patch[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."patch/?func=detailitem&amp;item_id=\\1\" class=\"italic\">patch&nbsp;#\\1</a>", $line);
 
 
 
@@ -387,7 +391,7 @@ function utils_user_link ($username, $realname=0)
       $re = '<a href="'.$GLOBALS['sys_home'].'users/'.$username.'">';
       if ($realname)
 	{
-	  $re .= $realname;
+	  $re .= $realname." &lt;".$username."&gt;";
 	}
       else
 	{
@@ -505,6 +509,7 @@ function GraphResult($result,$title)
   utils_graph_result($result, $title);
 }
 
+# DEPRECATED:
 function utils_graph_result ($result,$title)
 {
 
@@ -551,13 +556,14 @@ function utils_graph_result ($result,$title)
 }
 
 
-# deprecated name
+# DEPRECATED: deprecated name
 function GraphIt ($name_string,$value_string,$title)
 {
   utils_graph_it($name_string,$value_string,$title);
 }
 
 
+# DEPRECATED:
 function utils_graph_it ($name_string,$value_string,$title)
 {
 
