@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.25 2004/03/13 18:22:06 yeupou Exp $
+# $Id: index.php,v 1.26 2004/06/26 08:02:16 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -27,16 +27,52 @@
 
 require '../include/pre.php';
 
+if ($_POST['group_id'])
+   { 
+   $group_id = $_POST['group_id']; 
+   }
+elseif ($_GET['group_id'])
+   { 
+   $group_id = $_GET['group_id']; 
+   }
+
 if (!$group_id) 
 {
   $group_id = $GLOBALS['sys_group_id'];
 }
 
+if ($_POST['limit'])
+   { 
+   $limit= $_POST['limit']; 
+   }
+elseif ($_GET['limit'])
+   { 
+   $group_id = $_GET['limit']; 
+   }
+   
 if (!isset($limit)) 
 { 
   $limit = 10;  
 }
 
+if ($_POST['feedback'])
+   { 
+   $feedback = $_POST['feedback']; 
+   }
+elseif ($_GET['feedback'])
+   { 
+   $feedback = $_GET['feedback']; 
+   }
+   
+if ($_POST['group'])
+   { 
+   $group = $_POST['group']; 
+   }
+elseif ($_GET['group'])
+   { 
+   $group = $_GET['group']; 
+   }
+   
 $project=project_get_object($group_id);
 if (!$project->Uses("news"))
 { exit_error(_("This project has turned off the news tool.")); }
