@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: submit.php,v 1.21 2004/03/13 18:22:06 yeupou Exp $
+# $Id: submit.php,v 1.22 2004/06/26 08:02:16 yeupou Exp $
 #
 # 
 #  Copyright 1999-2000 (c) The SourceForge Crew
@@ -27,6 +27,54 @@
 
 require "../include/pre.php";
 
+if ($_POST['group_id'])
+   { 
+   $group_id= $_POST['group_id']; 
+   }
+elseif ($_GET['group_id'])
+   { 
+   $group_id = $_GET['group_id']; 
+   }
+
+if ($_POST['post_changes'])
+   { 
+   $post_changes = $_POST['post_changes']; 
+   }
+   
+if ($_POST['summary'])
+   { 
+   $summary = $_POST['summary']; 
+   }
+   
+if ($_POST['details'])
+   { 
+   $details = $_POST['details']; 
+   }
+
+if ($_POST['feedback'])
+   { 
+   $feedback = $_POST['feedback']; 
+   }
+elseif ($_GET['feedback'])
+   { 
+   $feedback = $_GET['feedback']; 
+   }
+if ($_POST['group'])
+   { 
+   $group = $_POST['group']; 
+   }
+elseif ($_GET['group'])
+   { 
+   $group = $_GET['group']; 
+   }      
+if ($_POST['id'])
+   { 
+   $id = $_POST['id']; 
+   }
+elseif ($_GET['id'])
+   { 
+   $id = $_GET['id']; 
+   }      
 if (user_isloggedin()) 
 {
 
@@ -59,6 +107,7 @@ if (user_isloggedin())
     } 
   
   # News must be submitted from a project page
+ 
   
   if (!$group_id) 
     {
