@@ -1,30 +1,26 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: editgroupnotifications.php,v 1.4 2004/03/06 15:31:12 toddy Exp $
-//
-//
-//  This is a new page written by Yves Perrin (Yves.Perrin@cern.ch)
-//  Copyright 2003 (c)
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-//
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: editgroupnotifications.php,v 1.6 2004/03/26 17:27:52 yeupou Exp $
+#
+#  Copyright 2003-2004 (c) Yves Perrin <Yves.Perrin@cern.ch>
+#                          Mathieu Roy <yeupou--at--gnu.org>
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
 
 require "../../include/pre.php";
 require  ($GLOBALS['sys_urlroot'].'/include/vars.php');
@@ -36,7 +32,7 @@ session_require(array('group'=>$group_id,'admin_flags'=>'A'));
 if ($update)
 {
 
-  group_add_history ('Changed Public Info','',$group_id);
+  group_add_history ('Changed Group Notification Settings','',$group_id);
 
 
   $res_new = trackers_data_post_notification_settings($group_id, "bugs");
@@ -49,7 +45,7 @@ if ($update)
 
 }
 
-// update info for page
+# update info for page
 $res_grp = db_query("SELECT * FROM groups WHERE group_id=$group_id");
 if (db_numrows($res_grp) < 1)
 {
@@ -61,7 +57,7 @@ $row_grp = db_fetch_array($res_grp);
 site_project_header(array('title'=>_("Editing Notification settings"),'group'=>$group_id,'toptab'=>'ahome'));
 
 
-// ####################################### General Description
+# ####################################### General Description
 
 print '
 <form action="'.$PHP_SELF.'" method="post">
