@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.12 2004/03/13 18:22:06 yeupou Exp $
+# $Id: index.php,v 1.13 2004/06/26 08:02:16 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -24,8 +24,19 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-require "../include/pre.php";    
-
+require "../include/pre.php"; 
+ 
+ # lorenzo lorenzohgh@tuxedo-es.org 
+ # Declaring variables BY method 
+if ($_POST['group_id'])
+   { 
+   $group_id = $_POST['group_id']; 
+   }
+elseif ($_GET['group_id'])
+   { 
+   $group_id = $_GET['group_id']; 
+   }
+   
 if ((!$group_id) && $form_grp) {
 	$group_id=$form_grp;
 }
